==> smart_arrays_peaks-2.0.3.tar.gz: README.md <==
## Smart Arrays Peaks


### What the package can do for you
This package provides functions that detect peaks (maximum values) in one- or two-dimensional arrays. Peak detection (peak search, peak picking) does not simply mean finding maximum values. Data originating from measurements are often subject to noise, i.e. random small variations of the measured values. The provided algorithms therefore allow you to specify a noise value to suppress to exclude noise effects from peak search. 


### The major API functionalities
 
- class `PeakPicker1D`

This example will pick the positive and negative peaks in the entire `array` using the noise discriminator 2.0. The result contains the array indices of the found peaks.

`List<int> peakIndices = PeakPicker1D.detectPeaks(
       array, 0, array.length, 2.0, 0.0, PeakPicker1D.PICK_POSNEG, 0);`

      
- class `PeakPicker2D`:   
  
This example will pick the negative peaks in the entire `array2D` using the noise discriminator 2.0. The result contains the array indices (row/column pairs) of the found peaks.

`List<List<int>> peakIndices = PeakPicker2D.detectPeaks(
       array2D, 0, array2D.length,0,array2D[0].lebngth, 2.0, 0.00, PeakPicker1D.PICK_NEG, 0);`
      
 

#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Using this package
You need Dart 2.0 or later.

Import the package using:
- `import 'package:smart_arrays_peaks/smart_arrays.dart_peaks';`

### Related packages


[`smart_arrays_base`: Basic functions for 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_lorentz-gauss`: Compute Lorent-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

==> smart_arrays_peaks-2.0.4.tar.gz: README.md <==
## Smart Arrays Peaks


### What the package can do for you
This package provides functions that detect peaks (maximum values) in one- or two-dimensional arrays. Peak detection (peak search, peak picking) does not simply mean finding maximum values. Data originating from measurements are often subject to noise, i.e. random small variations of the measured values. The provided algorithms therefore allow you to specify a noise value to suppress to exclude noise effects from peak search. 


### The major API functionalities
 
- class `PeakPicker1D`

This example will pick the positive and negative peaks in the entire `array` using the noise discriminator 2.0. The result contains the array indices of the found peaks.

`List<int> peakIndices = PeakPicker1D.detectPeaks(
       array, 0, array.length, 2.0, 0.0, PeakPicker1D.PICK_POSNEG, 0);`

      
- class `PeakPicker2D`:   
  
This example will pick the negative peaks in the entire `array2D` using the noise discriminator 2.0. The result contains the array indices (row/column pairs) of the found peaks.

`List<List<int>> peakIndices = PeakPicker2D.detectPeaks(
       array2D, 0, array2D.length,0,array2D[0].lebngth, 2.0, 0.00, PeakPicker1D.PICK_NEG, 0);`
      
 

#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Using this package
You need Dart 2.0 or later.

Import the package using:
- `import 'package:smart_arrays_peaks/smart_arrays.dart_peaks';`

### Related packages


[`smart_arrays_base`: Basic functions for 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size.]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_lorentz-gauss`: Compute Lorentz-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

[`smart_signal_processing`: Fourier transform and more.]( https://pub.dartlang.org/packages/smart_signal_processing)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)
